@@ -1,6 +1,8 @@
 import datetime
 from typing import List, Tuple
 
+from django_secret_sharing.models import File
+
 
 class BaseBackend:
     def __init__(self, *args, **kwargs):
@@ -11,6 +13,18 @@ class BaseBackend:
             "subclasses of BaseBackend must provide a validate_file_refs() method"
         )
 
+    def delete_file(self, ref: str) -> bool:
+        raise NotImplementedError(
+            "subclasses of BaseBackend must provide a delete_file() method"
+        )
+
+    def delete_stale_files(
+        self, expired_files: List[File], existing_file_refs: List[str]
+    ) -> List[str]:
+        raise NotImplementedError(
+            "subclasses of BaseBackend must provide a delete_stale_files() method"
+        )
+
     def get_upload_path(self, id: str, filename: str) -> str:
         now = datetime.datetime.now()
         upload_path = f"uploads/{now.year}/{now.month}/{now.day}/{id}/{filename}"
