@@ -1,4 +1,4 @@
-from django.urls import path
+from django.urls import include, path
 
 from django_secret_sharing import views
 
